<?php

/**
 *
 * Plugin Name: Checkout.vn
 * Plugin URI: https://checkout.vn/
 * Description: Tích hợp thanh toán Checkout.vn vào WooCommerce
 * Author: Checkout.vn
 * Author URI: https://checkout.vn/
 * Version: 1.0.0
 * License: GNU GENERAL PUBLIC LICENSE, Version 3
 * Text Domain: checkout
 * Domain Path: /languages
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'WOO_CHECKOUT_DIR', plugin_dir_path( __FILE__ ) );
define( 'WOO_CHECKOUT_URL', plugins_url( '/', __FILE__ ) );


/**
 * Start the instance
 */
new WooCheckout();

class WooCheckout {
    static $default_settings = array(
		'add_province'                =>
			array(
				'enabled' => 'yes',
			)
	);

    /**
	 * Setup class.
	 *
	 * @since 1.0
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'init' ) );
	}

    /**
	 * Throw a notice if WooCommerce is NOT active
	 */
	public function notice_if_not_woocommerce() {
		$class = 'notice notice-warning';

		$message = __( 'Woo Checkout không thể chạy vì WooCommerce chưa active. vui lòng active plugin WooCommerce.',
			'woo-checkout' );

		printf( '<div class="%1$s"><p><strong>%2$s</strong></p></div>', $class, $message );
	}
    /**
	 * Run this method under the "init" action
	 */
	public function init() {

		// Load the localization feature
		//$this->i18n();

		if ( class_exists( 'WooCommerce' ) ) {
			// Run this plugin normally if WooCommerce is active
			$this->main();

			// Add "Settings" link when the plugin is active
			//add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'add_settings_link' ) );
		} else {
			// Throw a notice if WooCommerce is NOT active
			add_action( 'admin_notices', array( $this, 'notice_if_not_woocommerce' ) );
		}
	}
    /**
	 * The main method to load the components
	 */
	public function main() {
        if ( is_admin() ) {
			// Add the admin setting page
			include( WOO_CHECKOUT_DIR . 'inc/class-woocheckout-admin-page.php' );
			$this->Admin_Page = new WooCheckout_Admin_Page();

			// Add the notices class
			//include( WOO_VIET_DIR . 'inc/class-wooviet-notices.php' );
			//new WooViet_Notices();

		}
        $settings = self::get_settings();
        include( 'inc/class-woocheckout-payment.php' );

        add_filter( 'woocommerce_payment_gateways', function ( $methods ) {
            $methods[] = 'WooCheckout_Payment';
            return $methods;
        } );
    }
    /**
	 * The wrapper method to get the settings of the plugin
	 * @return array
	 */
    static function get_settings() {
		$settings = get_option( 'woo-checkout', self::$default_settings );
		$settings = wp_parse_args( $settings, self::$default_settings );

		return $settings;
	}

    public function add_settings_link( $links ) {
		$settings = array( '<a href="' . admin_url( 'admin.php?page=woo-checkout' ) . '">' . __( 'Settings', 'woo-checkout' ) . '</a>' );
		$links    = array_reverse( array_merge( $links, $settings ) );

		return $links;
	}
}
?>